@@ -683,7 +683,9 @@ static Class NSNullK;
 
   // We MUST, for all LDAP sources, update the bindDN and bindPassword
   // to the user's value if bindAsCurrentUser is set to true in the
-  // LDAP source configuration
+  // LDAP source configuration.
+  //
+  // We also update the baseDN of all sources.
   if (checkOK)
     {
       NSObject <SOGoDNSource> *currentSource;
@@ -697,6 +699,7 @@ static Class NSNullK;
           {
             [currentSource setBindDN: [currentSource lookupDNByLogin: _login]];
             [currentSource setBindPassword: _pwd];
+            [currentSource updateBaseDNFromLogin: _login];
           }
     }
 
@@ -834,6 +837,10 @@ static Class NSNullK;
     {
       currentSource = [_sources objectForKey: sourceID];
 
+      // We update the placeholder in the LDAP source if needed
+      if ([currentSource conformsToProtocol: @protocol(SOGoDNSource)])
+        [currentSource updateBaseDNFromLogin: theUID];
+
       // Use the provided domain during the lookup. If none is defined, use the source's one
       // so if there's a match based on the source's domain, the user ID will be associated
       // to the right source.
@@ -1075,7 +1082,7 @@ static Class NSNullK;
 
                   [self _retainUser: currentUser  withLogin: cacheUid];
                 }
-            }
+            } // if (newUser)
         }
     }
   else
