@@ -26,6 +26,15 @@
         this.init(futureMessageData);
       }
       this.uid = parseInt(futureMessageData.uid);
+      this.level = parseInt(futureMessageData.level);
+      this.first = parseInt(futureMessageData.first) === 1;
+      if (this.first) {
+        this.threadCount = parseInt(futureMessageData.count);
+        this.collapsed = (futureMessageData.collapsed === true);
+      }
+      else if (!isNaN(this.level) && this.level >= 0) {
+        this.threadMember = true;
+      }
     }
     else {
       // The promise will be unwrapped first
@@ -171,10 +180,11 @@
           index = this.$mailbox.uidsMap[oldUID];
           this.$mailbox.uidsMap[uid] = index;
           delete this.$mailbox.uidsMap[oldUID];
+          this.$mailbox.$messages[index].uid = this.uid;
 
           // Update messages list of mailbox
           _.forEach(['from', 'to', 'subject'], function(attr) {
-            _this.$mailbox.$messages[index][attr] = _this[attr];
+            _this.$mailbox.$messages[index][attr] = _this.editable[attr];
           });
         }
       }
@@ -273,12 +283,22 @@
    * @returns true if the message is not a draft and has more than one recipient
    */
   Message.prototype.allowReplyAll = function() {
+    var identities = _.map(this.$mailbox.$account.identities, 'email');
     var recipientsCount = 0;
-    recipientsCount = _.reduce(['to', 'cc'], _.bind(function(count, type) {
-      if (this[type])
-        return count + this[type].length;
-      else
+    recipientsCount = _.reduce(['to', 'cc', 'bcc', 'reply-to'], _.bind(function(count, type) {
+      var typeCount = 0;
+      if (this[type]) {
+        typeCount = this[type].length;
+        _.forEach(this[type], function(recipient) {
+          if (_.indexOf(identities, recipient.email) >= 0) {
+            typeCount--;
+          }
+        });
+        return count + typeCount;
+      }
+      else {
         return count;
+      }
     }, this), recipientsCount);
 
     return !this.isDraft && recipientsCount > 1;
@@ -528,7 +548,7 @@
   };
 
   /**
-   * @function $markAsFlaggedOrUnflagged
+   * @function toggleFlag
    * @memberof Message.prototype
    * @desc Add or remove a the \\Flagged flag on the current message.
    * @returns a promise of the HTTP operation
@@ -547,6 +567,24 @@
     });
   };
 
+  /**
+   * @function toggleThread
+   * @memberof Message.prototype
+   * @desc Collapse or expand mail thread
+   * @returns a promise of the HTTP operation
+   */
+  Message.prototype.toggleThread = function() {
+    var _this = this,
+        action = 'markMessageCollapse';
+
+    if (this.collapsed)
+      action = 'markMessageUncollapse';
+
+    this.collapsed = !this.collapsed;
+
+    return Message.$$resource.post(this.$absolutePath(), action);
+  };
+
   /**
    * @function $isLoading
    * @memberof Message.prototype
