@@ -134,7 +134,7 @@
     if (card) {
       if (!this.component.attendees || (options && options.organizerCalendar)) {
         // No attendee yet; initialize the organizer
-        this.initOrganizer(options? options.organizerCalendar : undefined);
+        this.initOrganizer(options? options.organizerCalendar : null);
       }
       if (card.$isList({expandable: true})) {
         // Decompose list members
@@ -143,7 +143,7 @@
           _.forEach(list.refs, function(ref) {
             attendee = {
               name: ref.c_cn,
-              email: ref.$preferredEmail(options? options.partial : undefined),
+              email: ref.$preferredEmail(options? options.partial : null),
               role: Attendees.ROLES.REQ_PARTICIPANT,
               partstat: 'needs-action',
               uid: ref.c_uid,
@@ -169,8 +169,10 @@
           uid: card.c_uid,
           domain: card.c_domain,
           isMSExchange: card.ismsexchange,
+          isGroup: card.$isList(),
+          isResource: card.isresource,
           name: card.c_cn,
-          email: card.$preferredEmail(),
+          email: card.$$email,
           role: Attendees.ROLES.REQ_PARTICIPANT,
           partstat: 'needs-action',
           $avatarIcon: card.$avatarIcon
@@ -631,7 +633,7 @@
       _this.currentEntries = _.flatMap(_this.component.organizer.freebusy[startDay]);
       for (i = 0; i < _this.component.attendees.length; i++) {
         attendee = _this.component.attendees[i];
-        if (attendee.role !== Attendees.ROLES.NON_PARTICIPANT) {
+        if (attendee.freebusy && attendee.role !== Attendees.ROLES.NON_PARTICIPANT) {
           attendeeEntries = _.flatMap(attendee.freebusy[startDay]);
           for (j = 0; j < _this.currentEntries.length; j++) {
             _this.currentEntries[j] += attendeeEntries[j];
